==> igniteui-react-inputs-18.1.3.tgz: package/esm2015/lib/XCheckboxBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { XComponentBridge } from "./XComponentBridge";
import { runOn, delegateCombine, delegateRemove, markType } from "igniteui-react-core";
import { NativeUICheckboxChangeEventArgs } from "igniteui-react-core";
/**
 * @hidden
 */
export let XCheckboxBridge = /*@__PURE__*/ (() => {
    class XCheckboxBridge extends XComponentBridge {
        constructor(a) {
            super(a);
            this.d = null;
            this.e = null;
        }
        addHandler(a, b, c, d) {
            let e = a;
            switch (c) {
                case 2:
                    let f = a;
                    e.change = delegateCombine(e.change, runOn(this, this.f));
                    this.d = d;
                    this.e = b;
                    break;
            }
        }
        removeHandler(a, b, c, d) {
            let e = a;
            switch (c) {
                case 2:
                    e.change = delegateRemove(e.change, runOn(this, this.f));
                    this.d = null;
                    this.e = null;
                    break;
            }
        }
        f(a, b) {
            if (this.d != null) {
                let c = new NativeUICheckboxChangeEventArgs();
                this.d(this.e, c);
            }
        }
        getValue(a, b) {
            let c = a;
            switch (b) {
                case 4: return c.t;
                case 5: return c.checked;
            }
            return null;
        }
        setValue(a, b, c) {
            let d = a;
            switch (b) {
                case 4:
                    d.t = c;
                    return;
                case 5:
                    d.checked = c;
                    return;
            }
        }
    }
    XCheckboxBridge.$t = /*@__PURE__*/ markType(XCheckboxBridge, 'XCheckboxBridge', XComponentBridge.$);
    return XCheckboxBridge;
})();

==> igniteui-react-inputs-18.6.1.tgz: package/esm2015/lib/XCheckboxBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { XComponentBridge } from "./XComponentBridge";
import { runOn, delegateCombine, delegateRemove, enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { NativeUICheckboxChangeEventArgs } from "igniteui-react-core";
import { BaseControlTheme_$type } from "igniteui-react-core";
/**
 * @hidden
 */
export let XCheckboxBridge = /*@__PURE__*/ (() => {
    class XCheckboxBridge extends XComponentBridge {
        constructor(a) {
            super(a);
            this.u = null;
            this.v = null;
        }
        addHandler(a, b, c, d) {
            let e = a;
            switch (c) {
                case 2:
                    let f = a;
                    e.change = delegateCombine(e.change, runOn(this, this.w));
                    this.u = d;
                    this.v = b;
                    break;
            }
        }
        removeHandler(a, b, c, d) {
            let e = a;
            switch (c) {
                case 2:
                    e.change = delegateRemove(e.change, runOn(this, this.w));
                    this.u = null;
                    this.v = null;
                    break;
            }
        }
        w(a, b) {
            if (this.u != null) {
                let c = new NativeUICheckboxChangeEventArgs();
                this.u(this.v, c);
            }
        }
        getValue(a, b) {
            let c = a;
            switch (b) {
                case 4: return c.y;
                case 7: return c.checked;
                case 18: return enumGetBox(BaseControlTheme_$type, c.n);
                case 17: return c.ar;
            }
            return null;
        }
        setValue(a, b, c) {
            let d = a;
            switch (b) {
                case 4:
                    d.y = c;
                    return;
                case 7:
                    d.checked = c;
                    return;
                case 18:
                    d.n = EnumUtil.getEnumValue(BaseControlTheme_$type, c);
                    break;
                case 17:
                    d.ar = c;
                    break;
            }
        }
    }
    XCheckboxBridge.$t = /*@__PURE__*/ markType(XCheckboxBridge, 'XCheckboxBridge', XComponentBridge.$);
    return XCheckboxBridge;
})();
